/**
@file
@verbatim
$Id: FourCC.h 3096 2005-06-21 20:07:11Z ekuznetsov $

Copyright (c) 2003-2004 DivX, Inc. All rights reserved.

This software is the confidential and proprietary information of DivX, Inc.,
Inc. and may be used only in accordance with the terms of your license from
DivX, Inc.

@endverbatim
*/

#ifndef INCLUDED_FourCC
#define INCLUDED_FourCC

#include "DivXPortable.h" /* for uint32_t */

#ifdef __cplusplus
extern "C" {
#endif

/// Four Character Code used to decribe the media type of both compressed
/// and uncompressed video.
typedef uint32_t FourCC;


/// Creates a FourCC from a four-character string like "divx". 
/// @param str Pointer to a string such as "divx" 
/// @return Created FourCC.
FourCC FourCC_create(const char* str);


/// A mechanism to create a FourCC from four characters.
#define FOURCC(A, B, C, D) ( \
    ((FourCC) A) | \
    (((FourCC) B)<<8) | \
    (((FourCC) C)<<16) | \
    (((FourCC) D)<<24) )


/// Renders a FourCC to an ASCII string. 
/// @param fourCC FourCC code to be rendered. 
/// @param str Pointer to buffer where string will be rendered. 
/// @return Returns str for convenience. 
char* FourCC_toStr(char* str, FourCC fourCC);


/// Converts all letters 'A' to 'Z' present in fourCC to their lower case equivalent.
/// @param fourCC FourCC code to be converted. 
/// @return Converted FourCC.
FourCC FourCC_lowerCase(FourCC fourCC);


#ifdef __cplusplus
}
#endif

#endif /* INCLUDED_FourCC */
