/**
@file
@verbatim
$Id: Cli.h 3096 2005-06-21 20:07:11Z ekuznetsov $

Copyright (c) 2004 DivX, Inc. All rights reserved.

This software is the confidential and proprietary information of DivX, Inc.,
Inc. and may be used only in accordance with the terms of your license from
DivX, Inc.

@endverbatim
*/


#ifndef _Q_Cli_h
#define _Q_Cli_h

#include "./Settings.h"

#include <string>
#include <ostream>


/// Contains functions for CLI string generation and intepretation.
namespace Cli
{
    /// Produces a CLI string representing current settings.
    void render(std::string& cli, const Settings& settings);

    /// Sets a static variable that modifies the behavior of the next
    /// call to Cli::render().
    void showDisabledSettingsInNextCliRender( void );

    /// Changes settings according to the contents of a CLI string.
    void parse(Settings& settings, const std::string& cli);

    /// Encodes a binary data block into a base-64 textual representation.
    static void base64Encode(const uint8_t* buffer, int size, char* string);

    /// Decodes a base-64-encoded string into a binary data block.
    static void base64Decode(const char* string, uint8_t* buffer, int* size);
};


/// Serialization operator for encoder settings.  Renders the 
/// current settings to an output stream for storage.  This is
/// an alternate front end to Cli::render().
std::ostream & operator<<(std::ostream &stream, const Settings& settings);


/// Serialization operator for encoder settings.  Parses the input
/// stream and changes settings accordingly.  This is
/// an alternate front end to Cli::parse().
std::istream & operator>>(std::istream &stream, Settings& settings);


#endif
