/**
@file
@verbatim
$Id: DivXException.h 3096 2005-06-21 20:07:11Z ekuznetsov $

Copyright (c) 2003-2004 DivX, Inc. All rights reserved.

This software is the confidential and proprietary information of DivX, Inc.,
Inc. and may be used only in accordance with the terms of your license from
DivX, Inc.

@endverbatim
*/


#ifndef _ENCORE_DivXException
#define _ENCORE_DivXException

#ifdef WIN32
struct _EXCEPTION_POINTERS;
#endif

class DivXException
{
    int value;
    const char* file;
    int line;
#ifdef WIN32
    int except_code;
    struct _EXCEPTION_POINTERS* m_pExInfo;
#endif
public:
    DivXException(int v, const char* f, int l);
#ifdef WIN32
    DivXException(int v, struct _EXCEPTION_POINTERS* pExInfo);
    int GetExceptCode() const { return except_code; }
    struct _EXCEPTION_POINTERS* GetExceptInformation() const { return m_pExInfo; }
#endif
    int GetValue() const {return value;}
    const char* GetFile() const {return file;}
    int GetLine() const {return line;}
};

#define EXCEPTION(X) DivXException(X, __FILE__, __LINE__)

#define ENC_BUFFER         -2 /**< Returned by encore() when bitstream is too long for the buffer provided by caller.  Only returned by special builds of the codec that test for buffer overflow. */
#define ENC_FAIL           -1 /**< Returned by encore() when call failed. */
#define ENC_OK              0 /**< Returned by encore() when call was successful. */
#define ENC_MEMORY          1 /**< Returned by encore() when encoder has failed to allocated sufficient memory. */
#define ENC_BAD_FORMAT      2 /**< Returned by encore() if input video format proposed by user is not supported. */
#define ENC_INTERNAL        3 /**< Returned by encore() if there was an internal problem. */

#endif
