/**
@file
@verbatim
$Id: EncoderCallback.h 3096 2005-06-21 20:07:11Z ekuznetsov $

Copyright (c) 2002-2005 DivX, Inc. All rights reserved.

This software is the confidential and proprietary information of DivX, Inc.,
Inc. and may be used only in accordance with the terms of your license from
DivX, Inc.

@endverbatim
*/

#ifndef EncoderCallback_h
#define EncoderCallback_h

/// Abstract class representing an object that receives callback messages
/// from an encoder.  Virtual functions within this class allow the encoder
/// to prompt the user, update progress of slow encode actions and to ask
/// the user yes/no questions.
class EncoderCallback 
{
public:
    virtual ~EncoderCallback();
public:    
    virtual int getVersion();
public:
    virtual void enable(bool enable) = 0;
    virtual bool promptYesNo(const char* caption, const char* msg, bool bdefault) = 0;
    virtual void errorMessage(const char* caption, const char* msg) = 0;
    virtual void setProgress(bool enable, int percent, const char* caption, const char* msg) = 0;
public:
    static const char* strError;
    static const char* strWarning;
    static const char* strQuestion;

    static const char* strProblemReadingLogFile;
    static const char* strFailedOpenLogFileWrite;
    static const char* strFailedOpenLogFileRead;
    static const char* strFailedWriteLogFile;
    static const char* strBitrateTooLow;
    static const char* strInvalidLogFile;
    static const char* strIncompatibleLogFile;
    static const char* strOverwriteLogFile;
    static const char* strPlanningStrategy;
    static const char* strApplyingVbvConstraints;
    static const char* strFrameRateTooHighForProfile;
    static const char* strMacroblockRateTooHighForProfile;
    static const char* strUnsupportedColorspace;
    static const char* strWidthNotMod4;
    static const char* strHeightNotMod2;
    static const char* strWidthInvalid;
    static const char* strHeightInvalid;
};

#endif
