/**
@file
@verbatim
$Id: FeedbackInterface.h 3096 2005-06-21 20:07:11Z ekuznetsov $

Copyright (c) 2004 DivX, Inc. All rights reserved.

This software is the confidential and proprietary information of DivX, Inc.,
Inc. and may be used only in accordance with the terms of your license from
DivX, Inc.

@endverbatim
*/


#ifndef __FeedbackInterface_h
#define __FeedbackInterface_h


#include "../common/DivXPortable.h"
#include "../common/Cpu.h"

#include <string.h>
#include <vector>

#ifdef DISABLE_FEEDBACKINTERFACE
#define DEBUG_VIRTUAL inline
#else
#define DEBUG_VIRTUAL virtual
#endif


/// Base class representing an object that can receive feedback during encoding.
class FeedbackInterface
{
public:
    DEBUG_VIRTUAL ~FeedbackInterface() {}
    DEBUG_VIRTUAL void setDimensions(int width, int height) {}    
    DEBUG_VIRTUAL void setMacroblockDouble(const char* type, int x, int y, double value) {}
    DEBUG_VIRTUAL void setFrameDouble(const char* type, double value) {}
    DEBUG_VIRTUAL void setEncodingDouble(const char* type, double value) {}
    DEBUG_VIRTUAL void setFramePointerType(int index, const char* name) {}
    DEBUG_VIRTUAL int getActiveImage() {return -1;}
    DEBUG_VIRTUAL void setFramePointers(const char* name, const unsigned char* pY, const unsigned char* pU, const unsigned char* pV,
        int iStrideY, int iStrideUV) {}
    DEBUG_VIRTUAL void notifyBeginFrame(int frame) {}
    DEBUG_VIRTUAL bool notifyEndFrame(int) {return false;}

    /// Provides textual debug information to the feedback object.
    /// @param level Detail level of the trace.
    ///  - 0 - no tracing 
    ///  - 1 - codec level tracing     
    ///  - 2 - frame level tracing     
    ///  - 3 - slice level tracing     
    ///  - 4 - macroblock level tracing
    ///  - 5 - bitstream level tracing 
    DEBUG_VIRTUAL void print(int level, const char* fmt, ...) {}

#ifdef DISABLE_FEEDBACKINTERFACE
    static inline void cleanup() {}
#else
    static inline void cleanup() { Cpu_cleanup(); }
#endif
};


#endif
